pub struct BlockResponseED {Show 27 fields
pub difficulty: U64ED,
pub gas_limit: U64ED,
pub gas_used: U64ED,
pub hash: B256ED,
pub logs_bloom: B2048ED,
pub nonce: U64ED,
pub number: U64ED,
pub timestamp: U64ED,
pub mine_timestamp: U128ED,
pub transactions: Either<Vec<B256ED>, Vec<TxED>>,
pub base_fee_per_gas: U64ED,
pub transactions_root: B256ED,
pub uncles: Vec<B256ED>,
pub withdrawals: Vec<B256ED>,
pub withdrawals_root: B256ED,
pub total_difficulty: U64ED,
pub parent_beacon_block_root: B256ED,
pub parent_hash: B256ED,
pub receipts_root: B256ED,
pub sha3_uncles: B256ED,
pub size: U64ED,
pub state_root: B256ED,
pub miner: AddressED,
pub mix_hash: B256ED,
pub excess_blob_gas: U64ED,
pub extra_data: B256ED,
pub blob_gas_used: U64ED,
}Expand description
Represents a block response from BRC2.0 with all the fields required by the API.
Refer to Ethereum JSON-RPC documentation on eth_getBlockByHash for details
Fields
difficulty: U64EDThe difficulty of the block
gas_limit: U64EDThe gas limit of the block
gas_used: U64EDThe gas used by the block
hash: B256EDBlock hash
logs_bloom: B2048EDThe bloom filter for the logs in the block
nonce: U64EDThe nonce of the block
number: U64EDThe block number
timestamp: U64EDThe timestamp of the block
mine_timestamp: U128EDSpecific to BRC2.0, time it took to index the block
transactions: Either<Vec<B256ED>, Vec<TxED>>The transactions in the block
Can be a list of hashes or a list of transactions, depending on the call’s is_full flag
base_fee_per_gas: U64EDThe base fee per gas for the block, 0 for BRC2.0
transactions_root: B256EDThe root hash of the transactions in the block
uncles: Vec<B256ED>The uncles of the block, empty for BRC2.0
withdrawals: Vec<B256ED>The withdrawals of the block, empty for BRC2.0
withdrawals_root: B256EDThe root hash of the withdrawals in the block, empty for BRC2.0
total_difficulty: U64EDThe total difficulty of the block, 0 for BRC2.0
parent_beacon_block_root: B256EDThe parent beacon block root, empty for BRC2.0
parent_hash: B256EDThe parent hash of the block
receipts_root: B256EDThe root hash of the receipts in the block
sha3_uncles: B256EDThe sha3 uncles of the block, empty for BRC2.0
size: U64EDThe size of the block, not recorded for BRC2.0
state_root: B256EDThe root hash of the state in the block, not recorded for BRC2.0
miner: AddressEDThe miner of the block, not recorded for BRC2.0
mix_hash: B256EDThe mix hash of the block, not recorded for BRC2.0
excess_blob_gas: U64EDThe excess blob gas of the block, not recorded for BRC2.0, as it does not support blob transactions
extra_data: B256EDThe extra data of the block, not recorded for BRC2.0
blob_gas_used: U64EDThe blob gas used of the block, not recorded for BRC2.0, as it does not support blob transactions