pub struct Base64Bytes(/* private fields */);Expand description
A wrapper for base64 encoded bytes that can be serialized and deserialized. This struct is used to handle the encoding and decoding of bytes in the BRC20 protocol.
This struct supports compression and base64 encoding of the bytes.
Implementations
Sourceimpl Base64Bytes
impl Base64Bytes
Sourcepub fn new(inner: String) -> Self
pub fn new(inner: String) -> Self
Creates a new InscriptionBytes instance with the given inner string.
Sourcepub fn to_string(&self) -> String
pub fn to_string(&self) -> String
Returns the inner string if it exists, otherwise returns empty string.
Sourcepub fn from_bytes(bytes: Bytes) -> Result<Self, Box<dyn Error>>
pub fn from_bytes(bytes: Bytes) -> Result<Self, Box<dyn Error>>
Creates a new InscriptionBytes from the given bytes and the block height.
The bytes are encoded using either nada or zstd compression. The resulting string is base64 encoded and can be used for the data field in brc20 indexer methods.